@@ -362,6 +362,7 @@ void MainWindow::on_actionCreateNew_triggered(bool /*checked*/) {
 void MainWindow::on_actionOpen_triggered(bool /*checked*/) {
     //qDebug("open");
     Fm::FileDialog dlg{this};
+    dlg.setWindowTitle(tr("Open"));
     dlg.setFileMode(QFileDialog::ExistingFile);
     dlg.setNameFilters(Archiver::supportedOpenNameFilters() << tr("All files (*)"));
     //qDebug() << Archiver::supportedOpenMimeTypes();
@@ -391,6 +392,7 @@ void MainWindow::on_actionArchiveProperties_triggered(bool /*checked*/) {
 
 void MainWindow::on_actionAddFiles_triggered(bool /*checked*/) {
     Fm::FileDialog dlg{this};
+    dlg.setWindowTitle(tr("Add Files"));
     dlg.setFileMode(QFileDialog::ExistingFiles);
     dlg.setNameFilters(QStringList{} << tr("All files (*)"));
     dlg.setAcceptMode(QFileDialog::AcceptOpen);
@@ -423,6 +425,7 @@ void MainWindow::on_actionAddFiles_triggered(bool /*checked*/) {
 
 void MainWindow::on_actionAddFolder_triggered(bool /*checked*/) {
     Fm::FileDialog dlg{this};
+    dlg.setWindowTitle(tr("Add Folder"));
     dlg.setOptions(QFileDialog::ShowDirsOnly | QFileDialog::HideNameFilterDetails);
     dlg.setFileMode(QFileDialog::Directory);
     dlg.setNameFilters(QStringList{} << tr("All files (*)"));
@@ -1026,6 +1029,9 @@ QList<QStandardItem *> MainWindow::createFileListRow(const ArchiverItem *file) {
     if(mimeType) {
         auto iconInfo = mimeType->icon();
         desc = QString::fromUtf8(mimeType->desc());
+        if(auto link = file->link()) {
+            desc += QStringLiteral(" (%1)").arg(tr("Link to") + QChar(QChar::Space) + QString::fromUtf8(link));
+        }
         if(iconInfo) {
             icon = iconInfo->qicon();
         }
@@ -1036,7 +1042,7 @@ QList<QStandardItem *> MainWindow::createFileListRow(const ArchiverItem *file) {
 
     // FIXME: filename might not be UTF-8
     QString name = viewMode_ == ViewMode::FlatList ? QString::fromUtf8(file->fullPath()) : QString::fromUtf8(file->name());
-    auto nameItem = new QStandardItem{icon, name};
+    auto nameItem = new QStandardItem{icon, name.simplified()}; // no newline (fixed height)
     nameItem->setData(QVariant::fromValue(file), ArchiverItemRole); // store the item pointer on the first column
     nameItem->setEditable(false);
 
